@@ -20,12 +20,12 @@ __docformat__ = "restructuredtext"
 # import Zope3 interfaces
 
 # import local interfaces
-from layer import IGallerySkin
+from ztfy.gallery.skin.layer import IGallerySkin
 
 # import Zope3 packages
 
 # import local packages
-from ztfy.blog.browser.menu import SkinTargetMenuItem, SkinTargetJsMenuItem, SkinTargetDialogMenuItem
+from ztfy.skin.menu import SkinTargetMenuItem, SkinTargetJsMenuItem, SkinTargetDialogMenuItem
 
 
 class GallerySkinMenuItem(SkinTargetMenuItem):
