@@ -18,13 +18,12 @@ __docformat__ = "restructuredtext"
 # import standard packages
 
 # import Zope3 interfaces
-from zope.intid.interfaces import IIntIds
 
 # import local interfaces
 from ztfy.gallery.skin.layer import IGalleryLayer
 
 # import Zope3 packages
-from zope.component import adapts, getUtility
+from zope.component import adapts
 from zope.interface import Interface
 
 # import local packages
